//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

#import <Foundation/Foundation.h>
#import "NSDictionary+SafeValue.h"

@implementation NSDictionary (SafeValue)
- (nullable id)safeObjectForKey:(NSString *)key {
    id value = [self objectForKey:key];
    if (value == [NSNull null]) {
        return nil;
    }
    return value;
}
- (nullable id)safeStringForKey:(NSString *)key {
    id value = [self safeObjectForKey:key];
    if ([value isKindOfClass:[NSString class]]) {
        return value;
    }
    return nil;
}
- (nullable id)safeNumberForKey:(NSString *)key {
    id value = [self safeObjectForKey:key];
    if ([value isKindOfClass:[NSNumber class]]) {
        return value;
    }
    return nil;
}
- (nullable id)safeDateForKey:(NSString *)key {
    id value = [self safeObjectForKey:key];
    if ([value isKindOfClass:[NSString class]]) {
        NSDateFormatter* dateFormatter = [[NSDateFormatter alloc] init];
        if ([[value uppercaseString] hasSuffix:@"Z"]) {
            [dateFormatter setDateFormat:@"yyyy-MM-dd'T'HH:mm:ss'Z'"];
        }
        else {
            [dateFormatter setDateFormat:@"yyyy-MM-dd'T'HH:mm:ssZZZZZ"];
        }        
        return [dateFormatter dateFromString:value];
    }
    return nil;
}
@end
