//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import KakaoSDKCommon
import KakaoSDKAuth
import KakaoSDKUser
import KakaoSDKFriend

// KakaoSDKFriend 모듈의 @objc Wrapper 클래스 예제입니다.
// 아래 예시 외의 API들도 같은 형식으로 추가하여 사용 가능합니다.
// Objective-C에서 사용 불가능한 Swift 모델 클래스 프로퍼티는 [String:Any]? 타입으로 반환받아 사용할 수 있습니다.

@objc
class KakaoSDKFriendWrapper : NSObject {

    @objc
    public static let shared = KakaoSDKFriendWrapper()
    
    // 여러 명의 친구를 선택(멀티 피커)할 수 있는 친구 피커를 화면 전체에 표시합니다.
    @objc
    func selectFriends(completion:@escaping ([String:Any]?, Error?) -> Void) {
        let openPickerFriendRequestParams = OpenPickerFriendRequestParams(title: "샘플앱 친구피커",                     //default "카카오톡 친구 선택"
                                                                    serviceTypeFilter: .talk,                            //default .talk
                                                                    viewAppearance: .auto,                              //default .auto
                                                                    orientation: .auto,                                 //default .auto
                                                                    enableSearch: true,                                 //default true
                                                                    enableIndex: true,                                  //default true
                                                                    showMyProfile: true,                                //default true
                                                                    showFavorite: true,                                 //default true
                                                                    showPickedFriend: nil,                              //default true
                                                                    maxPickableCount: nil,                              //default 30
                                                                    minPickableCount: nil)                              //default 1
        
        PickerApi.shared.selectFriend(params: openPickerFriendRequestParams) { selectedUsers, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let selectedUsersData = try? SdkJSONEncoder.customDate.encode(selectedUsers) {
                    let selectedUsersInfo = try? JSONSerialization.jsonObject(with: selectedUsersData, options: .allowFragments) as? [String : Any]
                    completion(selectedUsersInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 여러 명의 친구를 선택(멀티 피커)할 수 있는 친구 피커를 팝업 형태로 표시합니다.
    @objc
    func selectFriendsPopup(completion:@escaping ([String:Any]?, Error?) -> Void) {
        let openPickerFriendRequestParams = OpenPickerFriendRequestParams(title: "샘플앱 친구피커",                     //default "카카오톡 친구 선택"
                                                                    serviceTypeFilter: .talk,                            //default .talk
                                                                    viewAppearance: .auto,                              //default .auto
                                                                    orientation: .auto,                                 //default .auto
                                                                    enableSearch: true,                                 //default true
                                                                    enableIndex: true,                                  //default true
                                                                    showMyProfile: true,                                //default true
                                                                    showFavorite: true,                                 //default true
                                                                    showPickedFriend: nil,                              //default true
                                                                    maxPickableCount: nil,                              //default 30
                                                                    minPickableCount: nil)                              //default 1
        
        PickerApi.shared.selectFriendsPopup(params: openPickerFriendRequestParams) { selectedUsers, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let selectedUsersData = try? SdkJSONEncoder.customDate.encode(selectedUsers) {
                    let selectedUsersInfo = try? JSONSerialization.jsonObject(with: selectedUsersData, options: .allowFragments) as? [String : Any]
                    completion(selectedUsersInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 위 메서드 형식을 참고해 이 외 필요한 메서드 추가
    // ...
}
