//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import KakaoSDKCommon
import KakaoSDKNavi

// KakaoSDKNavi 모듈의 @objc Wrapper 클래스 예제입니다.

@objc
class KakaoSDKNaviWrapper : NSObject {
    @objc
    public static let shared = KakaoSDKNaviWrapper()
    
    // 내비 설치 URL 조회
    @objc static var webNaviInstallUrl : URL {
        get {
            return NaviApi.webNaviInstallUrl
        }
    }
        
    // KATEC 좌표로 위치 공유하기
    @objc
    public func shareUrlForKatec() -> URL? {
        let destination = NaviLocation(name: "카카오판교오피스", x: "321286", y: "533707")
        return NaviApi.shared.shareUrl(destination: destination)
    }
    
    // WGS84 좌표로 위치 공유하기
    @objc
    public func shareUrlForWgs84() -> URL? {
        let destination = NaviLocation(name: "카카오판교오피스", x: "127.108640", y: "37.402111")
        let option = NaviOption(coordType: .WGS84)
        return NaviApi.shared.shareUrl(destination: destination, option: option)
    }
    
    // KATEC 좌표로 경유 위치 공유하기
    @objc
    public func navigateUrlForKatec() -> URL? {
        let destination = NaviLocation(name: "카카오판교오피스", x: "321286", y: "533707")
        let viaList = [NaviLocation(name: "판교역 1번출구", x: "321525", y: "532951")]
        return NaviApi.shared.navigateUrl(destination: destination, viaList:viaList)
    }
    
    // WGS84 좌표로 경유 위치 공유하기
    @objc
    public func navigateUrlForWgs84() -> URL? {
        let destination = NaviLocation(name: "카카오판교오피스", x: "127.108640", y: "37.402111")
        let option = NaviOption(coordType: .WGS84)
        let viaList = [NaviLocation(name: "판교역 1번출구", x: "127.111492", y: "37.395225")]
        return NaviApi.shared.navigateUrl(destination: destination, option:option, viaList:viaList)
    }
}
