//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import KakaoSDKCommon
import KakaoSDKShare
import KakaoSDKTemplate

// KakaoSDKShare 모듈의 @objc Wrapper 클래스 예제입니다.
// Objective-C에서 사용 불가능한 Swift 모델 클래스 프로퍼티는 [String:Any]? 타입으로 반환받아 사용할 수 있습니다.

@objc
class KakaoSDKShareWrapper : NSObject {

    @objc
    public static let shared = KakaoSDKShareWrapper()
    
    // 기본 템플릿으로 카카오톡 공유하기
    @objc
    public func shareDefault(templateJsonString: String, serverCallbackArgs:[String:String]? = nil, completion:@escaping ([String:Any]?, Error?) -> Void) {
        ShareApi.shared.shareDefault(templateObjectJsonString: templateJsonString,
                                     serverCallbackArgs:serverCallbackArgs) { sharingResult, error in
            
            if let error = error {
                completion(nil, error)
            }
            else {
                if let sharingResultData = try? SdkJSONEncoder.customDate.encode(sharingResult) {
                    let sharingResultInfo = try? JSONSerialization.jsonObject(with: sharingResultData, options: .allowFragments) as? [String : Any]
                    completion(sharingResultInfo, nil)
                    return
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
        
             
    }
    
    // 스크랩 템플릿으로 카카오톡 공유하기
    @objc
    public func shareScrap(requestUrl:String,
                           templateId:Int64,
                           templateArgs:[String:String]? = nil,
                           serverCallbackArgs:[String:String]? = nil,
                          completion:@escaping ([String:Any]?, Error?) -> Void ) {
        ShareApi.shared.shareScrap(requestUrl: requestUrl,
                                   templateId: templateId,
                                   templateArgs: templateArgs,
                                   serverCallbackArgs: serverCallbackArgs) { sharingResult, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let sharingResultData = try? SdkJSONEncoder.customDate.encode(sharingResult) {
                    let sharingResultInfo = try? JSONSerialization.jsonObject(with: sharingResultData, options: .allowFragments) as? [String : Any]
                    completion(sharingResultInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 커스텀 템플릿으로 카카오톡 공유하기
    @objc
    public func shareCustom(templateId:Int64,
                            templateArgs:[String:String]? = nil,
                            serverCallbackArgs:[String:String]? = nil,
                            completion:@escaping ([String:Any]?, Error?) -> Void ) {
        ShareApi.shared.shareCustom(templateId: templateId, templateArgs: templateArgs, serverCallbackArgs: serverCallbackArgs) { sharingResult, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let sharingResultData = try? SdkJSONEncoder.customDate.encode(sharingResult) {
                    let sharingResultInfo = try? JSONSerialization.jsonObject(with: sharingResultData, options: .allowFragments) as? [String : Any]
                    completion(sharingResultInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 이미지 업로드
    @objc
    public func imageUpload(image: UIImage, secureResource: Bool = true,
                            completion:@escaping ([String:Any]?, Error?) -> Void ) {
        ShareApi.shared.imageUpload(image: image, secureResource: secureResource) { imageUploadResult, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let imageUploadResultData = try? SdkJSONEncoder.customDate.encode(imageUploadResult) {
                    let imageUploadResultInfo = try? JSONSerialization.jsonObject(with: imageUploadResultData, options: .allowFragments) as? [String : Any]
                    completion(imageUploadResultInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 이미지 스크랩 하기
    @objc
    public func imageScrap(imageUrl: URL, secureResource: Bool = true,
                           completion:@escaping ([String:Any]?, Error?) -> Void ) {
        ShareApi.shared.imageScrap(imageUrl: imageUrl, secureResource: secureResource) { imageUploadResult, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let imageUploadResultData = try? SdkJSONEncoder.customDate.encode(imageUploadResult) {
                    let imageUploadResultInfo = try? JSONSerialization.jsonObject(with: imageUploadResultData, options: .allowFragments) as? [String : Any]
                    completion(imageUploadResultInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
}
