//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import KakaoSDKCommon
import KakaoSDKStory

// KakaoSDKStory 모듈의 @objc Wrapper 클래스 예제입니다.
// 아래 예시 외의 API들도 같은 형식으로 추가하여 사용 가능합니다.
// Objective-C에서 사용 불가능한 Swift 모델 클래스 프로퍼티는 [String:Any]? 타입으로 반환받아 사용할 수 있습니다.

@objc
class KakaoSDKStoryWrapper : NSObject {
    @objc
    public static let shared = KakaoSDKStoryWrapper()
   
    // 스토리 포스트 URL 여부 조회
    @objc
    public static func isStoryPostUrl(_ url:URL) -> Bool {
        return StoryApi.isStoryPostUrl(url)
    }
    
    // 스토리 사용자 여부 조회
    @objc
    public func isStoryUser(secureResource: Bool = true, completion:@escaping (Bool, Error?) -> Void) {
        StoryApi.shared.isStoryUser { isStoryUser, error in
            if let error = error {
                completion(false, error)
            }
            else {
                completion(isStoryUser ?? false, nil)
            }
        }
    }
  
    // 스토리 프로필 정보 가져오기
    @objc
    public func profile(secureResource: Bool = true, completion:@escaping ([String:Any]?, Error?) -> Void) {
        StoryApi.shared.profile { profile, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let profileData = try? SdkJSONEncoder.customDate.encode(profile) {
                    let profileInfo = try? JSONSerialization.jsonObject(with: profileData, options: .allowFragments) as? [String : Any]
                    completion(profileInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }
    
    // 위 형식을 참고해 이 외 필요한 메서드 추가
    // ...
}
