//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import Foundation
import KakaoSDKCommon
import KakaoSDKAuth
import KakaoSDKUser
import KakaoSDKTalk
import KakaoSDKTemplate

// KakaoSDKTalk 모듈의 @objc Wrapper 클래스 예제입니다.
// 아래 예시 외의 API들도 같은 형식으로 추가하여 사용 가능합니다.
// Objective-C에서 사용 불가능한 Swift 모델 클래스 프로퍼티는 [String:Any]? 타입으로 반환받아 사용할 수 있습니다.

@objc
class KakaoSDKTalkWrapper : NSObject {

    @objc
    public static let shared = KakaoSDKTalkWrapper()
    
    // 프로필 정보 가져오기
    @objc
    public func profile(completion:@escaping ([String:Any]?, Error?) -> Void) {
        TalkApi.shared.profile { profile, error in
            if let error = error {
                completion(nil, error)
            }
            else {
                if let profileData = try? SdkJSONEncoder.customDate.encode(profile) {
                    let profileInfo = try? JSONSerialization.jsonObject(with: profileData, options: .allowFragments) as? [String : Any]
                    completion(profileInfo, nil)
                }
                else {
                    completion(nil, SdkError(reason: .Unknown, message: "Encoding Failed"))
                }
            }
        }
    }

    // 나에게 메모 템플릿으로 보내기
    @objc
    public func sendCustomMemo(templateId: Int64, templateArgs: [String:String]? = nil, completion:@escaping (Error?) -> Void) {
        TalkApi.shared.sendCustomMemo(templateId: templateId, templateArgs: templateArgs) { error in
            if let error = error {
                completion(error)
            }
            else {
                completion(nil)
            }
        }
    }
    
    // 나에게 메모 기본 템플릿으로 보내기
    @objc
    public func sendDefaultMemo(templateJson: String, completion:@escaping (Error?) -> Void) {
        guard let templateJsonData = templateJson.data(using: .utf8) else {
            completion(SdkError(reason: .BadParameter, message:"json is nil"))
            return
        }
        
        if let templatable = try? SdkJSONDecoder.custom.decode(FeedTemplate.self, from:templateJsonData) {
            TalkApi.shared.sendDefaultMemo(templatable: templatable) { error in
                if let error = error {
                    completion(error)
                    
                }
                else {
                    completion(nil)
                }
            }
        }
        else {
            completion(SdkError(reason: .BadParameter, message: "invalid json"))
        }
    }

    
    // 나에게 메모 스크랩 템플릿으로 보내기
    // 참고: templateId는 nullable이지만 @objc에서 Int64?를 표현할 수 없으므로 적절하게 타입 변경해서 사용해야 합니다.
    @objc
    public func sendScrapMemo(requestUrl: String, templateId: Int64, templateArgs: [String:String]? = nil, completion:@escaping (Error?) -> Void) {
        TalkApi.shared.sendScrapMemo(requestUrl: requestUrl, templateId: templateId, templateArgs: templateArgs) { error in
            if let error = error {
                completion(error)
                return
            }
            else {
                completion(nil)
            }
        }
    }
    
    // 위 형식을 참고해 이 외 필요한 메서드 추가
    // ...
}
